"""
Name: AF_UCS_Test.py
Authors: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA
Contact: ryan.j.urbanowicz@darmouth.edu
Created: Feb. 12, 2010
---------------------------------------------------------------------------------------------------------------------------------------------------------
AF_UCS Version 1.0: An learning classifier system algorithm implemented with our new attribute tracking and feedback strategy for modeling epistasis and heterogeneity 
data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRENTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python
#Import modules
from AF_UCS_Algorithm import *
from AF_UCS_Environment import *
import time
import sys

#options_trainFile = "ExampleData_Train.txt"
#options_testFile = "ExampleData_Test.txt"  #None

options_trainFile = "ExampleData_Train_ID.txt"
options_testFile = "ExampleData_Test_ID.txt"  #None

options_outFile = "AF_UCS_LOCALRUN"
options_remakeFile = 'False' #"AF_UCS_LOCALRUN_CompactTest_new_50000" 

options_environment = "SNP"

options_learnIterations = '5000.10000' #'5000.10000.50000.100000.500000''
options_defaultRuleDelete = False

#GLOBAL_PARAMETERS-------------------------------------------------------------------------------
#Mechanisms
options_subsumption = True #[Boolean] Do subsumption?  !!!!!!might wantto change to allow for NOne, both or either action or GA only subsumption!!!!!
options_selection = "tournament" #tournament or roulette
options_covering = "smart" #[string] type of population initialization
options_mutation = True #[Boolean] use mutation operator
options_crossover = "uc" #[string] use crossover? what type of crossover
options_EK_type = 'newLogit'#'simpleTransformation' #simpleTransformation, simpleLogit
options_p_rule_search = False #0.0001#0.001  
options_fitcalc = "accuracy" #"acc_coverage"#"accuracy" #"acc_gen_exp"

#Constants
options_popSize = 1000 #[int] max size of population 
options_crossVal = True 
options_trackFreq = 0 #[int] how often to print tracking summary
options_beta = 0.2 # [float] learning parameter
options_theta_GA = 25 # GA activation experience threshold
options_pX = 0.8 # The probability of applying crossover in an offspring classifier.
options_fitRed = 0.1 #The reduction in fitness received when GA is employed 
options_theta_Sel = 0.5 # The fraction of the action set to be included in tournament selection.
options_wild = "#"
options_accuracyIni = 0.0
options_fitnessIni = 0.01#0.01
options_p_nocare = 0.5
options_pMut = 0.08   # 0.04
options_theta_Sub = 20
options_accZ = 0.99
options_delta = 0.1  
options_theta_Del = 20
options_fitnessPower = 10#5 #10

#options_DCP = 0.5
options_EK_max = '0.4' #'0.49' #this is b
options_EK_dop = 5

options_coverGenerality = 0.5 #'maxgen', 'alternate', 'halfprob'
options_attDisc = 'Spec' #Spec, FWSpec, AWSpec
options_attributeTracking = True
options_attributeFeedback = True
options_attributePunish = False
options_attributeID = True
options_EK_apply = 'cover' #cover, mutation, both
options_attDiv = False

cons.setRunOps(options_popSize, options_crossVal, options_trackFreq, options_trainFile, options_testFile, options_environment, options_learnIterations, options_remakeFile, options_defaultRuleDelete)
cons.setConstants(options_beta, options_theta_GA, options_pX, options_fitRed, options_theta_Sel, options_wild, options_accuracyIni, options_fitnessIni, options_p_nocare, options_pMut, options_theta_Sub, options_accZ, options_delta, options_theta_Del, options_fitnessPower)
cons.setMech(options_subsumption, options_selection, options_covering, options_mutation, options_crossover, options_p_rule_search, options_fitcalc, options_coverGenerality, options_attDisc, options_attributeTracking, options_attributeFeedback, options_attDiv, options_attributePunish,options_attributeID)

#------------------------------------------------------------------------------------------------
#Engage Timer
timer = Timer()
    
#Establish Environment
if options_environment == 'SNP':
    e = Environment()
    e = SNP_Environment(options_trainFile, options_testFile, options_remakeFile)
else:
    print "Algorithm is not set up to handle requested environment."
    
#Instantiate and Run AF_UCS
afucs = AF_UCS(e, options_outFile, options_learnIterations, timer, options_remakeFile) # arguments include the environment, output file's root name, and the unparsed learning iterations

cons.refEnv(e)

afucs.runAF_UCS() 
