"""
Name: AF_UCS_SNP_Enviroment.py
Authors: Ryan Urbanowicz - written at Dartmouth College, Hanover, NH, USA
Contact: ryan.j.urbanowicz@darmouth.edu
Created: Feb. 12, 2010
---------------------------------------------------------------------------------------------------------------------------------------------------------
AF_UCS Version 1.0: An learning classifier system algorithm implemented with our new attribute tracking and feedback strategy for modeling epistasis and heterogeneity 
data mining and classification tasks.
Copyright (C) 2013 Ryan Urbanowicz 
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the 
Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABLILITY 
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, 
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
---------------------------------------------------------------------------------------------------------------------------------------------------------
"""

#!/usr/bin/env python
#Import modules
from AF_UCS_Environment import *
from AF_UCS_Constants import *
import random
import sys
import copy
from random import *
from random import shuffle
import math

class SNP_Environment(Environment):
    numClasses = 2 #cases and controls
    attributeCombos = 3 # number of alleles possible for each SNP
    
    def __init__(self, trainFile, testFile, remakeFile):
        """ Initialize environment objects. """

        # Data set Descriptors
        self.numAttributes = 0  # Saves the number of attributes in the input file.
        self.numTrainSamples = 0
        self.numTestSamples = 0
        
        # Data set Objects
        self.headerList = []
        self.datasetList = []

        #For Dictionary representation
        self.headerDict = {}
        self.headerRefDict = {} #also for expert knowledge

        if testFile == None or testFile == 'None':
            pass
        elif cons.attributeID:
            self.fTestData = self.formatDataID(testFile,False)
            print "Length of Testing Data Set = " + str(len(self.fTestData))
        else:
            self.fTestData = self.formatData(testFile,False)
            print "Length of Testing Data Set = " + str(len(self.fTestData))
            
        if remakeFile == 'False' or remakeFile == False:
            if cons.attributeID:
                print "Accounting for Attribute ID's"
                self.fTrainData = self.formatDataID(trainFile,True)
                print "Length of Training Data Set = " + str(len(self.fTrainData))
            else:
                self.fTrainData = self.formatData(trainFile,True)
                print "Length of Training Data Set = " + str(len(self.fTrainData))
            #Attribute Tracking - Initialize lists
            numAttributes = len(self.fTrainData[0][0])
            self.fTrainAttTrack = [[0]*numAttributes for i in range(len(self.fTrainData))]
            self.fTrainAttCount = [[0]*numAttributes for i in range(len(self.fTrainData))]
            self.fTrainAttPunCount = [[0]*numAttributes for i in range(len(self.fTrainData))]
            self.fTrainAttPunTrack = [[0]*numAttributes for i in range(len(self.fTrainData))]
            ###################
            
        else: #Remake Train Dataset and Att track from AttTrack File
            self.fTrainData = self.formatDataRemake(remakeFile)
            print "Length of Training Data Set = " + str(len(self.fTrainData))
            
        
        #Set environmental constants.
        cons.setEnvCons(self.attributeCombos, self.numClasses, len(self.fTrainData))

        if cons.attributeID:
            self.attributeIDList = []
            for i in range(len(self.fTrainData)):
                self.attributeIDList.append(self.fTrainData[i][2])  
            print self.attributeIDList
        # Holds current instance from data set - can be either training or testing.
        self.dataCount = 0
        self.correct = False 
        
        #Initialize first training and testing data samples
        self.currentTrainState = self.fTrainData[self.dataCount][0]
        self.currentTrainClass = self.fTrainData[self.dataCount][1]
        if testFile == None or testFile == 'None':
            pass
        else:
            self.currentTestState = self.fTrainData[self.dataCount][0]
            self.currentTestClass = self.fTrainData[self.dataCount][1]

                          
    def formatData(self, dataset, doTrain):
        """ Encodes and formats the data set to prepare it to be iteratively sent to the algorithm. """
        SNP0 = ['0']
        SNP1 = ['1']
        SNP2 = ['2'] 
        other = ['#']
        
        #*******************Initial file handling**********************************************************
        try:       
            datasetList = []
            f = open(dataset, 'r')
            self.headerList = f.readline().rstrip('\n').split('\t')   #strip off first row

            #Dictionary Rule Rep.
            for i in range(len(self.headerList)): # make dictionary referencing SNP name to it's column reference
                self.headerDict[self.headerList[i]] = i
            for i in range(len(self.headerList)): # make dictionary referencing SNP name to it's column reference
                self.headerRefDict[str(i)] = self.headerList[i]
                
            for line in f:
                lineList = line.strip('\n').split('\t')
                datasetList.append(lineList)
            f.close()
            
            self.numAttributes = len(self.headerList) - 1 # subtract 1 to account for the class column
            classPosition = len(self.headerList) - 1    # Could be altered to look for "class" header
            if doTrain:
                self.numTrainSamples = len(datasetList)  
            else:
                self.numTestSamples = len(datasetList)
            
        except IOError, (errno, strerror):
            print ("Could not Read File!")
            print ("I/O error(%s): %s" % (errno, strerror))
            raise
        except ValueError:
            print ("Could not convert data to an integer.")
            raise
        except:
            print ("Unexpected error:", sys.exc_info()[0])
            raise
        #**************************************************************************************************
        #NOISE TESTING
        #for i in range(self.numAttributes):
        #    self.noiseWeights[0].append(1)
        #    self.noiseWeights[1].append(1)
        ######################################
        
        formatedDataset = []
        # Build empty matrix for formated data where each attribute gets it's own position in a list + class is at last position.
        for i in range(len(datasetList)):  # for each column - one for the attribute data and one for the class
            formatedDataset.append([])
        for i in range(len(datasetList)):
            formatedDataset[i] = [' ', ' ']
             
        # Fill in the matrix built above with the binary attribute encoding and the binary class value    
        for line in range(len(datasetList)):
            codeList = []
            for att in range(self.numAttributes):
                if datasetList[line][att] == '0': #might need to be double checked /think thru
                    codeList.append(SNP0[0])

                elif datasetList[line][att] == '1':
                    codeList.append(SNP1[0])

                elif datasetList[line][att] == '2':
                    codeList.append(SNP2[0])
                else:
                    codeList.append(other[0])
                    
            formatedDataset[line][0] = codeList
            formatedDataset[line][1] = datasetList[line][classPosition]                         


        from random import shuffle
        shuffle(formatedDataset) 
            
        return formatedDataset 


    def formatDataID(self, dataset, doTrain):
        """ Encodes and formats the data set to prepare it to be iteratively sent to the algorithm. """
        SNP0 = ['0']
        SNP1 = ['1']
        SNP2 = ['2'] 
        other = ['#']
        
        #*******************Initial file handling**********************************************************
        try:       
            datasetList = []
            f = open(dataset, 'r')
            tempList = f.readline().rstrip('\n').split('\t')   #strip off first row
            print len(tempList)
            #self.headerList = tempList[1:]
            self.headerList = tempList[1:]
            print self.headerList
            #Dictionary Rule Rep.
            for i in range(len(self.headerList)): # make dictionary referencing SNP name to it's column reference
                self.headerDict[self.headerList[i]] = i
            for i in range(len(self.headerList)): # make dictionary referencing SNP name to it's column reference
                self.headerRefDict[str(i)] = self.headerList[i]
                
            for line in f:
                lineList = line.strip('\n').split('\t')
                datasetList.append(lineList)
            f.close()
            
            self.numAttributes = len(self.headerList) - 1 # subtract 2 to account for the class column and ID column
            print self.numAttributes
            classPosition = len(self.headerList)     # Could be altered to look for "class" header
            sampleIDPosition = 0    # Could be altered to look for "class" header
            if doTrain:
                self.numTrainSamples = len(datasetList)  
            else:
                self.numTestSamples = len(datasetList)
            
        except IOError, (errno, strerror):
            print ("Could not Read File!")
            print ("I/O error(%s): %s" % (errno, strerror))
            raise
        except ValueError:
            print ("Could not convert data to an integer.")
            raise
        except:
            print ("Unexpected error:", sys.exc_info()[0])
            raise
        #**************************************************************************************************
        #NOISE TESTING
        #for i in range(self.numAttributes):
        #    self.noiseWeights[0].append(1)
        #    self.noiseWeights[1].append(1)
        ######################################
        
        formatedDataset = []
        # Build empty matrix for formated data where each attribute gets it's own position in a list + class is at last position.
        for i in range(len(datasetList)):  # for each column - one for the attribute data and one for the class
            formatedDataset.append([])
        for i in range(len(datasetList)):
            formatedDataset[i] = [' ', ' ', ' ']
             
        # Fill in the matrix built above with the binary attribute encoding and the binary class value    
        for line in range(len(datasetList)):
            codeList = []
            for att in range(1,self.numAttributes+1):
                if datasetList[line][att] == '0': #might need to be double checked /think thru
                    codeList.append(SNP0[0])

                elif datasetList[line][att] == '1':
                    codeList.append(SNP1[0])

                elif datasetList[line][att] == '2':
                    codeList.append(SNP2[0])
                else:
                    codeList.append(other[0])
                    
            formatedDataset[line][0] = codeList
            formatedDataset[line][1] = datasetList[line][classPosition]                         
            formatedDataset[line][2] = datasetList[line][sampleIDPosition]  

        from random import shuffle
        shuffle(formatedDataset) 
            
        return formatedDataset 
    

    def formatDataRemake(self, dataset):
        """ Encodes and formats the data set to prepare it to be iteratively sent to the algorithm. """
        SNP0 = ['0']
        SNP1 = ['1']
        SNP2 = ['2'] 
        other = ['#']
        
        #*******************Initial file handling**********************************************************
        try:       
            datasetList = []
            f = open(dataset+"_AttTrack.txt", 'r') 
            self.headerList = f.readline().rstrip('\n').split('\t')   #strip off first row
            #Find number of attributes
            sumAtts = int((len(self.headerList)-1)/2) #file has all atts two times, minus class label

            #Dictionary Rule Rep.
            for i in range(sumAtts): # make dictionary referencing SNP name to it's column reference
                self.headerDict[self.headerList[i]] = i
            for i in range(sumAtts): # make dictionary referencing SNP name to it's column reference
                self.headerRefDict[str(i)] = self.headerList[i]
                
            for line in f:
                lineList = line.strip('\n').split('\t')
                datasetList.append(lineList)
            f.close()
            self.numAttributes = sumAtts # subtract 1 to account for the class column
            classPosition = len(self.headerList) - 1    # Could be altered to look for "class" header

            self.numTrainSamples = len(datasetList)  

        except IOError, (errno, strerror):
            print ("Could not Read File!")
            print ("I/O error(%s): %s" % (errno, strerror))
            raise
        except ValueError:
            print ("Could not convert data to an integer.")
            raise
        except:
            print ("Unexpected error:", sys.exc_info()[0])
            raise
        
        formatedDataset = []
        # Build empty matrix for formated data where each attribute gets it's own position in a list + class is at last position.
        for i in range(len(datasetList)):  # for each column - one for the attribute data and one for the class
            formatedDataset.append([])
        for i in range(len(datasetList)):
            formatedDataset[i] = [' ', ' ']
             
        self.fTrainAttTrack = [[0]*sumAtts for i in range(len(datasetList))]
            
        # Fill in the matrix built above with the binary attribute encoding and the binary class value    
        for line in range(len(datasetList)):
            for att in range(sumAtts): #Remakes Att track list
                self.fTrainAttTrack[line][att] = datasetList[line][att]
                
            codeList = []
            for att in range(sumAtts,len(datasetList[0])-1):
                if datasetList[line][att] == '0': #might need to be double checked /think thru
                    codeList.append(SNP0[0])

                elif datasetList[line][att] == '1':
                    codeList.append(SNP1[0])

                elif datasetList[line][att] == '2':
                    codeList.append(SNP2[0])
                else:
                    codeList.append(other[0])
                    
            formatedDataset[line][0] = codeList
            formatedDataset[line][1] = datasetList[line][classPosition]                         
            
        return formatedDataset 
    
    
    def resetDataCount(self):
        """ Resets the iteration count through the current data set. """
        self.dataCount = 0  #NOT SPECIFIC TO ONE TYPE OF DATASET - make sure to reset when switching between
        
        
    def resetState(self, isTrain): 
        """  Changes the state to the next sample input.  Once all of the data has been explored, the order is shuffled and it is explored again. """
        if isTrain:
            if self.dataCount < (self.numTrainSamples)-1:
                self.dataCount += 1
                self.currentTrainState = self.fTrainData[self.dataCount][0]
                self.currentTrainClass = self.fTrainData[self.dataCount][1]

            else:   # This is done so that the training order varies with each epoch.
                self.dataCount = 0
                self.currentTrainState = self.fTrainData[self.dataCount][0]
                self.currentTrainClass = self.fTrainData[self.dataCount][1]
        else:
            if self.dataCount < (self.numTestSamples):
                self.currentTestState = self.fTestData[self.dataCount][0]
                self.currentTestClass = self.fTestData[self.dataCount][1]
                self.dataCount += 1
            else:   # This is done so that the training order varies with each epoch.
                self.dataCount = 0
                print "Environment: Testing out of range."    
                
              
    def gaussianFun(self, x): #x is (1-percent) complete
        a = 1#peak height
        b = 0.5 #center of peak (half way through percent)
        c = 0.2#width of bell, should be in terms of values applicable to x /// 0.2 leaves about 5% of max start stop
        y = a*math.exp(math.pow(x-b,2)/(-2*math.pow(c,2)))
        return y
        
        
    def updateRAINWeight(self, weights):
        """updates new noise weight lists"""
        self.RAINWeights = weights
        
        
    def getTrainState(self, eval=False, percent=0):
        """ Returns the current training state (set of attributes). """
        return [self.currentTrainState, self.currentTrainClass]
                        
            
    def updateTrainAttTrack(self, correctSet, matchSet):
        """ Attribute Tracking: written by Ambrose: """
        if cons.attributePunish:
            #Identify rules from match set that are not in correct set
            incorrectSet = []
            for rule in matchSet.clSet:
                if rule not in correctSet.clSet:
                    #print "incorect rule found"
                    incorrectSet.append(rule)
            
            counts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            justcounts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            punjustcounts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            puncounts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            
            #Add Accuracy to Attributes in rules of the correct set
            for rule in correctSet.clSet:
                for i in range(len(rule.condition)):
                    if rule.condition[i] != cons.wild:
                        counts[i]+=rule.accuracy
                        justcounts[i]+= 1
                        
            #Subtract Accuracy from Attributes in rules of the incorrect set.
            for rule in incorrectSet:
                for i in range(len(rule.condition)):
                    if rule.condition[i] != cons.wild:
                        puncounts[i]+=rule.accuracy
                        punjustcounts[i]+= 1
                            
            for i in range(len(counts)):
                self.fTrainAttTrack[self.dataCount][i]+=counts[i]
                self.fTrainAttCount[self.dataCount][i]+=justcounts[i]
                self.fTrainAttPunCount[self.dataCount][i]+=punjustcounts[i]
                self.fTrainAttPunTrack[self.dataCount][i]+=puncounts[i]
        else:
            counts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            justcounts = [0 for i in range(len(self.fTrainAttTrack[0]))]
            for rule in correctSet.clSet:
                for i in range(len(rule.condition)):
                    if rule.condition[i] != cons.wild:
                        counts[i]+=rule.accuracy
                        justcounts[i]+= 1
            for i in range(len(counts)):
                self.fTrainAttTrack[self.dataCount][i]+=counts[i]
                self.fTrainAttCount[self.dataCount][i]+=justcounts[i]
              

    def getTestState(self):
        """ Returns the current training state (set of attributes). """
        return [self.currentTestState, self.currentTestClass]
    
    
    def getNumTrainSamples(self):
        """ Returns the number of samples in the data set being examined. """        
        return self.numTrainSamples
    
    
    def getNumTestSamples(self):
        """ Returns the number of samples in the data set being examined. """        
        return self.numTestSamples
    
    
    def getHeaderList(self):
        """ Returns the file header text as a list of elements. """
        return self.headerList
    
    
    def getNumAttributes(self):
        """ Returns the number of attributes in the data set. """
        return self.numAttributes
    
    
    def getAttTrack(self):
        """ Returns the list of attribute track values. """
        return self.fTrainAttTrack[self.dataCount-1]
    
    
    def getCountTrack(self):
        """ Returns the list of attribute track values. """
        return self.fTrainAttCount[self.dataCount-1]
    
    
    def getCountPunTrack(self):
        """ Returns the list of attribute track values. """
        return self.fTrainAttPunCount[self.dataCount-1]
    
    
    def getAttPunTrack(self):
        """ Returns the list of attribute track values. """
        return self.fTrainAttPunTrack[self.dataCount-1]
